@@ -20,9 +20,7 @@ from lean.click import LeanCommand
 from lean.container import container
 from lean.models.api import (QCEmailNotificationMethod, QCNode, QCNotificationMethod, QCSMSNotificationMethod,
                              QCWebhookNotificationMethod)
-from lean.models.brokerages import (BitfinexBrokerage, CloudBrokerage, CoinbaseProBrokerage, FXCMBrokerage,
-                                    InteractiveBrokersBrokerage, OANDABrokerage, PaperTradingBrokerage,
-                                    TradierBrokerage)
+from lean.models.brokerages.cloud import all_cloud_brokerages
 from lean.models.logger import Option
 
 
@@ -109,19 +107,9 @@ def live(project: str, push: bool, open_browser: bool) -> None:
     cloud_runner = container.cloud_runner()
     finished_compile = cloud_runner.compile_project(cloud_project)
 
-    brokerages = [
-        PaperTradingBrokerage(),
-        InteractiveBrokersBrokerage(),
-        TradierBrokerage(),
-        FXCMBrokerage(),
-        OANDABrokerage(),
-        BitfinexBrokerage(),
-        CoinbaseProBrokerage()
-    ]
+    brokerage_options = [Option(id=brokerage, label=brokerage.name) for brokerage in all_cloud_brokerages]
 
-    brokerage_options = [Option(id=brokerage, label=brokerage.name) for brokerage in brokerages]
-
-    brokerage: CloudBrokerage = logger.prompt_list("Select a brokerage", brokerage_options)
+    brokerage = logger.prompt_list("Select a brokerage", brokerage_options)
     brokerage_settings = brokerage.get_settings(logger)
     price_data_handler = brokerage.get_price_data_handler()
 
@@ -173,19 +161,18 @@ def live(project: str, push: bool, open_browser: bool) -> None:
                   default=False,
                   abort=True)
 
-    api_client.live.start(cloud_project.projectId,
-                          finished_compile.compileId,
-                          node.id,
-                          brokerage_settings,
-                          price_data_handler,
-                          automatic_redeploy,
-                          cloud_project.leanVersionId,
-                          notify_order_events,
-                          notify_insights,
-                          notify_methods)
+    live_algorithm = api_client.live.start(cloud_project.projectId,
+                                           finished_compile.compileId,
+                                           node.id,
+                                           brokerage_settings,
+                                           price_data_handler,
+                                           automatic_redeploy,
+                                           cloud_project.leanVersionId,
+                                           notify_order_events,
+                                           notify_insights,
+                                           notify_methods)
 
-    live_url = cloud_project.get_url().replace("#open", "#openLive")
-    logger.info(f"Live url: {live_url}")
+    logger.info(f"Live url: {live_algorithm.get_url()}")
 
     if open_browser:
-        webbrowser.open(live_url)
+        webbrowser.open(live_algorithm.get_url())
