@@ -148,6 +148,8 @@ def optimize(project: str, name: Optional[str], push: bool) -> None:
 
     backtest_count = _calculate_backtest_count(optimization_parameters)
 
+    organization = api_client.organizations.get(cloud_project.organizationId)
+
     while True:
         node, parallel_nodes = optimizer_config_manager.configure_node()
 
@@ -168,6 +170,8 @@ def optimize(project: str, name: Optional[str], push: bool) -> None:
         logger.info(f"Estimated number of backtests: {backtest_count:,}")
         logger.info(f"Estimated batch time: {_format_hours(batch_time)}")
         logger.info(f"Estimated batch cost: ${batch_cost:,.2f}")
+        logger.info(
+            f"Organization balance: {organization.credit.balance:,.0f} QCC (${organization.credit.balance / 100:,.2f})")
 
         if click.confirm("Do you want to start the optimization on the selected node type?", default=True):
             break
@@ -184,7 +188,8 @@ def optimize(project: str, name: Optional[str], push: bool) -> None:
 
     backtests = optimization.backtests.values()
     backtests = [b for b in backtests if b.exitCode == 0]
-    backtests = [b for b in backtests if _backtest_meets_constraints(b, optimization_constraints)]
+    backtests = [b for b in backtests if
+                 _backtest_meets_constraints(b, optimization_constraints)]
 
     if len(backtests) == 0:
         logger.info("No optimal parameter combination found, no successful backtests meet all constraints")
@@ -197,7 +202,8 @@ def optimize(project: str, name: Optional[str], push: bool) -> None:
     parameters = ", ".join(f"{key}: {optimal_backtest.parameterSet[key]}" for key in optimal_backtest.parameterSet)
     logger.info(f"Optimal parameters: {parameters}")
 
-    optimal_backtest = api_client.backtests.get(cloud_project.projectId, optimal_backtest.id)
+    optimal_backtest = api_client.backtests.get(cloud_project.projectId,
+                                                optimal_backtest.id)
 
     logger.info(f"Optimal backtest id: {optimal_backtest.backtestId}")
     logger.info(f"Optimal backtest name: {optimal_backtest.name}")
