@@ -28,18 +28,19 @@ from QuantConnect.Algorithm import QCAlgorithm
 
 class $NAME$(QCAlgorithm):
     def Initialize(self):
-        self.SetStartDate(2020, 8, 2)  # Set Start Date
+        self.SetStartDate(2013, 10, 7)  # Set Start Date
+        self.SetEndDate(2013, 10, 11)  # Set End Date
         self.SetCash(100000)  # Set Strategy Cash
-        # self.AddEquity("SPY", Resolution.Minute)
+        self.AddEquity("SPY", Resolution.Minute)
 
     def OnData(self, data):
         """OnData event is the primary entry point for your algorithm. Each new data point will be pumped in here.
             Arguments:
                 data: Slice object keyed by symbol containing the stock data
         """
-        # if not self.Portfolio.Invested:
-        #     self.SetHoldings("SPY", 1)
-        #     self.Debug("Purchased Stock")
+        if not self.Portfolio.Invested:
+            self.SetHoldings("SPY", 1)
+            self.Debug("Purchased Stock")
 '''.strip() + "\n"
 
 DEFAULT_PYTHON_NOTEBOOK = """
@@ -111,20 +112,21 @@ namespace QuantConnect.Algorithm.CSharp
     {
         public override void Initialize()
         {
-            SetStartDate(2020, 8, 2); // Set Start Date
+            SetStartDate(2013, 10, 7); // Set Start Date
+            SetEndDate(2013, 10, 11); // Set Start Date
             SetCash(100000); // Set Strategy Cash
-            // AddEquity("SPY", Resolution.Minute);
+            AddEquity("SPY", Resolution.Minute);
         }
 
         /// OnData event is the primary entry point for your algorithm. Each new data point will be pumped in here.
         /// Slice object keyed by symbol containing the stock data
         public override void OnData(Slice data)
         {
-            // if (!Portfolio.Invested)
-            // {
-            //     SetHoldings("SPY", 1);
-            //     Debug("Purchased Stock");
-            // }
+            if (!Portfolio.Invested)
+            {
+                SetHoldings("SPY", 1);
+                Debug("Purchased Stock");
+            }
         }
     }
 }
@@ -192,16 +194,16 @@ DEFAULT_CSHARP_NOTEBOOK = """
     ],
     "metadata": {
         "kernelspec": {
-            "display_name": "C#",
-            "language": "csharp",
-            "name": "csharp"
+            "display_name": ".NET (C#)",
+            "language": "C#",
+            "name": ".net-csharp"
         },
         "language_info": {
             "file_extension": ".cs",
             "mimetype": "text/x-csharp",
             "name": "C#",
-            "pygments_lexer": "c#",
-            "version": "4.0.30319"
+            "pygments_lexer": "csharp",
+            "version": "9.0"
         }
     },
     "nbformat": 4,
