@@ -35,8 +35,10 @@ def _check_docker_output(chunk: str, port: int) -> None:
 
 
 @click.command(cls=LeanCommand, requires_lean_config=True, requires_docker=True)
-@click.argument("project", type=PathParameter(exists=True, file_okay=False, dir_okay=True))
-@click.option("--port", type=int, default=8888, help="The port to run Jupyter Lab on (defaults to 8888)")
+@click.argument("project",
+                type=PathParameter(exists=True, file_okay=False, dir_okay=True))
+@click.option("--port", type=int, default=8888,
+              help="The port to run Jupyter Lab on (defaults to 8888)")
 @click.option("--image",
               type=str,
               help=f"The LEAN research image to use (defaults to {DEFAULT_RESEARCH_IMAGE})")
@@ -125,6 +127,7 @@ def research(project: Path, port: int, image: Optional[str], update: bool) -> No
     try:
         docker_manager.run_image(research_image, **run_options)
     except APIError as error:
-        if "port is already allocated" in error.explanation:
+        msg = error.explanation
+        if isinstance(msg, str) and "port is already allocated" in msg:
             raise RuntimeError(f"Port {port} is already in use, please specify a different port using --port <number>")
         raise error
