@@ -86,8 +86,8 @@ class LeanConfigManager:
         config = self.get_lean_config()
         return self.get_cli_root_directory() / config["data-folder"]
 
-    def set_property(self, key: str, value: str) -> None:
-        """Sets a string property in the Lean config file.
+    def set_property(self, key: str, value: Any) -> None:
+        """Sets a property in the Lean config file.
 
         If the property does not exist yet it is added automatically.
         Comments in the Lean config file are preserved.
@@ -100,11 +100,13 @@ class LeanConfigManager:
         config_path = self.get_lean_config_path()
         config_text = config_path.read_text(encoding="utf-8")
 
+        json_value = json5.dumps(value)
+
         # We can only use regex to set the property because converting the config back to JSON drops all comments
         if key in config:
-            config_text = re.sub(fr'"{key}":\s*"([^"]*)"', f'"{key}": "{value}"', config_text)
+            config_text = re.sub(fr'"{key}":\s*("?[^",]*"?)', f'"{key}": {json_value}', config_text)
         else:
-            config_text = config_text.replace("{", f'{{\n  "{key}": "{value}",', 1)
+            config_text = config_text.replace("{", f'{{\n  "{key}": {json_value},', 1)
 
         config_path.write_text(config_text, encoding="utf-8")
 
@@ -163,16 +165,16 @@ class LeanConfigManager:
     def get_complete_lean_config(self,
                                  environment: str,
                                  algorithm_file: Path,
-                                 debugging_method: Optional[DebuggingMethod]) -> Dict[str, Any]:
+                                 debugging_method: Optional[DebuggingMethod],
+                                 data_purchase_limit: Optional[int]) -> Dict[str, Any]:
         """Returns a complete Lean config object containing all properties needed for the engine to run.
 
         This retrieves the path of the config, parses the file and adds all properties removed in clean_lean_config().
 
-        It is assumed that the default LEAN Docker image is used.
-
         :param environment: the environment to set
         :param algorithm_file: the path to the algorithm that will be ran
         :param debugging_method: the debugging method to use, or None to disable debugging
+        :param data_purchase_limit: the data purchase limit in QCC
         """
         config = self.get_lean_config()
 
@@ -188,6 +190,9 @@ class LeanConfigManager:
             config["debugging"] = False
             config["debugging-method"] = "LocalCmdline"
 
+        if data_purchase_limit is not None:
+            config["data-purchase-limit"] = data_purchase_limit
+
         config["job-user-id"] = self._cli_config_manager.user_id.get_value(default="0")
         config["api-access-token"] = self._cli_config_manager.api_token.get_value(default="")
 
