@@ -52,16 +52,17 @@ class LeanRunner:
         self._temp_manager = temp_manager
 
     def run_lean(self,
+                 lean_config: Dict[str, Any],
                  environment: str,
                  algorithm_file: Path,
                  output_dir: Path,
                  image: DockerImage,
-                 debugging_method: Optional[DebuggingMethod],
-                 data_purchase_limit: Optional[int]) -> None:
+                 debugging_method: Optional[DebuggingMethod]) -> None:
         """Runs the LEAN engine locally in Docker.
 
         Raises an error if something goes wrong.
 
+        :param lean_config: the LEAN configuration to use
         :param environment: the environment to run the algorithm in
         :param algorithm_file: the path to the file containing the algorithm
         :param output_dir: the directory to save output data to
@@ -72,7 +73,7 @@ class LeanRunner:
 
         # The dict containing all options passed to `docker run`
         # See all available options at https://docker-py.readthedocs.io/en/stable/containers.html
-        run_options = self.get_basic_docker_config(environment, algorithm_file, output_dir, debugging_method)
+        run_options = self.get_basic_docker_config(lean_config, algorithm_file, output_dir, debugging_method)
 
         # Set up PTVSD debugging
         if debugging_method == DebuggingMethod.PTVSD:
@@ -96,11 +97,7 @@ class LeanRunner:
                 "mode": "rw"
             }
 
-        lean_command = "exec dotnet QuantConnect.Lean.Launcher.dll"
-        if data_purchase_limit is not None:
-            lean_command += f" --data-purchase-limit {data_purchase_limit}"
-
-        run_options["commands"].append(lean_command)
+        run_options["commands"].append("exec dotnet QuantConnect.Lean.Launcher.dll")
 
         # Run the engine and log the result
         success = self._docker_manager.run_image(image, **run_options)
@@ -117,7 +114,7 @@ class LeanRunner:
                 f"Something went wrong while running '{relative_project_dir}' in the '{environment}' environment, the output is stored in '{relative_output_dir}'")
 
     def get_basic_docker_config(self,
-                                environment: str,
+                                lean_config: Dict[str, Any],
                                 algorithm_file: Path,
                                 output_dir: Path,
                                 debugging_method: Optional[DebuggingMethod]) -> Dict[str, Any]:
@@ -125,10 +122,9 @@ class LeanRunner:
 
         This method constructs the parts of the Docker config that is the same for both the engine and the optimizer.
 
-        :param environment: the environment to run the algorithm in
+        :param lean_config: the LEAN configuration to use
         :param algorithm_file: the path to the file containing the algorithm
         :param output_dir: the directory to save output data to
-        :param image: the LEAN engine image to run
         :param debugging_method: the debugging method if debugging needs to be enabled, None if not
         :return: the Docker configuration containing basic configuration to run Lean
         """
@@ -143,18 +139,13 @@ class LeanRunner:
         if not storage_dir.exists():
             storage_dir.mkdir(parents=True)
 
-        # Create a file containing the complete Lean configuration
-        config = self._lean_config_manager.get_complete_lean_config(environment,
-                                                                    algorithm_file,
-                                                                    debugging_method)
-
-        config["data-folder"] = "/Lean/Data"
-        config["results-destination-folder"] = "/Results"
-        config["object-store-root"] = "/Storage"
+        lean_config["data-folder"] = "/Lean/Data"
+        lean_config["results-destination-folder"] = "/Results"
+        lean_config["object-store-root"] = "/Storage"
 
         config_path = self._temp_manager.create_temporary_directory() / "config.json"
         with config_path.open("w+", encoding="utf-8") as file:
-            file.write(json.dumps(config, indent=4))
+            file.write(json.dumps(lean_config, indent=4))
 
         # The dict containing all options passed to `docker run`
         # See all available options at https://docker-py.readthedocs.io/en/stable/containers.html
@@ -274,6 +265,7 @@ class LeanRunner:
         # Create a .csproj file to compile with
         with (compile_dir / f"{project_dir.name}.csproj").open("w+", encoding="utf-8") as file:
             libraries = self._project_config_manager.get_csharp_libraries(project_dir)
+            libraries = [library for library in libraries if not library.name.startswith("QuantConnect.")]
             package_references = "\n".join(
                 f'<PackageReference Include="{library.name}" Version="{library.version}" />' for library in libraries)
 
@@ -285,7 +277,7 @@ class LeanRunner:
         <TargetFramework>net5.0</TargetFramework>
         <LangVersion>9</LangVersion>
         <GenerateAssemblyInfo>false</GenerateAssemblyInfo>
-        <OutputPath>/Lean/Launcher/bin/Debug</OutputPath>
+        <OutputPath>/LeanCLI/bin/Debug</OutputPath>
         <AppendTargetFrameworkToOutputPath>false</AppendTargetFrameworkToOutputPath>
         <AutoGenerateBindingRedirects>true</AutoGenerateBindingRedirects>
         <GenerateBindingRedirectsOutputType>true</GenerateBindingRedirectsOutputType>
@@ -322,3 +314,10 @@ class LeanRunner:
 
         # Build the project before running LEAN
         run_options["commands"].append(f'dotnet build "/LeanCLI/{project_dir.name}.csproj"')
+
+        # Copy over the algorithm DLL
+        run_options["commands"].append(
+            f'cp "/LeanCLI/bin/Debug/{project_dir.name}.dll" "/Lean/Launcher/bin/Debug/{project_dir.name}.dll"')
+
+        # Copy over all library DLLs that don't already exist in /Lean/Launcher/bin/Debug
+        run_options["commands"].append(f"cp -R -n /LeanCLI/bin/Debug/. /Lean/Launcher/bin/Debug/")
