@@ -11,9 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Any, List
+import sys
+from typing import Any, List, Optional
 
 import click
+import maskpass
 from rich.console import Console
 from rich.progress import BarColumn, Progress, TextColumn
 
@@ -99,3 +101,26 @@ class Logger:
                     return option.id
 
             self.info("Please enter the number or label of an option")
+
+    def prompt_password(self, text: str, default: Optional[str] = None) -> str:
+        """Asks the user for a string value while masking the given input.
+
+        :param text: the text to display before prompting
+        :param default: the default value if no input is given
+        :return: the given input
+        """
+        if default is not None:
+            text = f"{text} [{'*' * len(default)}]"
+
+        # Masking does not work when the input is not coming from a keyboard
+        if not sys.stdout.isatty():
+            return click.prompt(text, default=default, show_default=False)
+
+        while True:
+            user_input = maskpass.askpass(f"{text}: ")
+
+            if len(user_input) == 0 and default is not None:
+                return default
+
+            if len(user_input) > 0:
+                return user_input
