@@ -160,7 +160,7 @@ class ProjectManager:
             "pathMappings": [
                 {
                     "localRoot": "${workspaceFolder}",
-                    "remoteRoot": "/Lean/Launcher/bin/Debug"
+                    "remoteRoot": "/LeanCLI"
                 }
             ]
         }
@@ -217,7 +217,7 @@ class ProjectManager:
       <PathMappingSettings>
         <option name="pathMappings">
           <list>
-            <mapping local-root="$PROJECT_DIR$" remote-root="/Lean/Launcher/bin/Debug" />
+            <mapping local-root="$PROJECT_DIR$" remote-root="/LeanCLI" />
           </list>
         </option>
       </PathMappingSettings>
@@ -307,7 +307,7 @@ class ProjectManager:
             "name": "Debug with Lean CLI",
             "request": "attach",
             "type": "coreclr",
-            "processId": "${command:pickRemoteProcess}",
+            "processId": "1",
             "pipeTransport": {
                 "pipeCwd": "${workspaceRoot}",
                 "pipeProgram": "docker",
@@ -340,7 +340,7 @@ class ProjectManager:
         <NoWarn>CS0618</NoWarn>
     </PropertyGroup>
     <ItemGroup>
-        <PackageReference Include="QuantConnect.Lean" Version="2.5.11586"/>
+        <PackageReference Include="QuantConnect.Lean" Version="2.5.11940"/>
     </ItemGroup>
 </Project>
         """)
